==> metabar-0.6.tar.gz: metabar/src/metascrollview.h <==
/***************************************************************************
 *   Copyright (C) 2005 by Florian Roth   *
 *   florian@synatic.net   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef _METASCROLLVIEW_H_
#define _METASCROLLVIEW_H_

#include <qscrollview.h>
#include <qevent.h>

#include "metabar_widget.h"
 
class MetaScrollView : public QScrollView
{
  Q_OBJECT

  public:
    MetaScrollView(MetabarWidget *metabar, QWidget *parent = 0, const char *name = 0);
    ~MetaScrollView();
    
  public slots:
    void resizeContents ( int w, int h );
  
  protected:
    void resizeEvent(QResizeEvent *event);
    
  private:
    MetabarWidget *metabarWidget;
};

#endif

==> metabar_0.7.orig.tar.gz: metabar/src/metascrollview.h <==
/***************************************************************************
 *   Copyright (C) 2005 by Florian Roth   *
 *   florian@synatic.net   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef _METASCROLLVIEW_H_
#define _METASCROLLVIEW_H_

#include <qscrollview.h>
#include <qevent.h>

#include "metabar_widget.h"
 
class MetaScrollView : public QScrollView
{
  Q_OBJECT

  public:
    MetaScrollView(MetabarWidget *metabar, QWidget *parent = 0, const char *name = 0);
    ~MetaScrollView();
  
  protected:
    void resizeEvent(QResizeEvent *);
    void viewportResizeEvent(QResizeEvent *);
    
  private:
    MetabarWidget *metabarWidget;
};

#endif
